<?php
/*
 nce (ntch cloud environment.)
 name: account.php
 author: Akira Ohta (akohta001.gmail.com)
 date: 2013-apr-13th
 License: GPLv3
 */
include_once "user.php";
include_once "database.php";
include_once "http_util.php";


$ERROR_MSG;

function getUser($user_name){
	global $db;
	global $nc_ACCOUNTTABLE_NAME;
	$result;
$sql_sel_user = <<< SELECT_USER
select user_pass, seed, home_url
from $nc_ACCOUNTTABLE_NAME where user_name = '{$user_name}'
SELECT_USER;
	try{
		$db->open();
		$result = $db->execute($sql_sel_user);
		$db->close();
	}catch(Exception $e){
		$error = __FILE__."(".__LINE__.") UserID '{$user_name}' couldn't be found in the database.".
		"\n$sql_sel_user\n";
		nc_logging($error, $e);
		return FALSE;
	}
	if(!$result || $result->num_rows != 1){
		//print_r($result);
		return FALSE;
	}
	$row = $result->fetch_assoc();
	//$user = new nc_User();
	if(!isset($row['user_pass']) ||
		!isset($row['seed']) ||
		!isset($row['home_url'])){
		return FALSE;
	}
	$user = new nc_User(
		$user_name,
		$row['user_pass'],
		$row['home_url'],
		$row['seed']
	);
	return $user;
}

function chk_file_name(&$val){
	if(!isset($val)){
		return false;
	}
	if(0 == strlen($val)){
		return false;
	}
	if(FALSE === inspect_file_name($val)){
		return false;
	}
	return true;
}

function chk_param(&$val){
	if(!isset($val)){
		return false;
	}
	if(0 == strlen($val)){
		return false;
	}
	if(FALSE === inspect_base64_param($val)){
		return false;
	}
	return true;
}


function chk_passwd(&$user_id, &$token){
	global $ERROR_MSG;
	
	if(!chk_param($user_id) || !chk_param($token)){
		$ERROR_MSG = ERROR302;
		return FALSE;
	}

	$user = getUser($user_id);
	if(!$user){
		$ERROR_MSG = ERROR300;
		return FALSE;
	}

	if(FALSE == $user->checkPassword($token)){
		$ERROR_MSG = ERROR301;
		return FALSE;
	}
	return $user;
}
?>
